==> bazar1.4.11.zip: bazar1.4.1/woocommerce/content-single-product.php <==
<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * Override this template by copying it to yourtheme/woocommerce/content-single-product.php
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     1.6.4
 */                
wp_enqueue_script( 'jquery-selectbox' );   

// grouped fix
global $product;
if ( $product->product_type == 'grouped' && yit_get_option('shop-detail-show-price') ) {
    remove_action( 'yit_product_box', 'woocommerce_template_single_add_to_cart', 20 );
    add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
}
?>

<?php
	/**
	 * woocommerce_before_single_product hook
	 *
	 * @hooked woocommerce_show_messages - 10
	 */
	 do_action( 'woocommerce_before_single_product' );
?>
<div class="row">
    

    	<?php
    		/**
    		 * woocommerce_show_product_images hook
    		 *
    		 * @hooked woocommerce_show_product_sale_flash - 10
    		 * @hooked woocommerce_show_product_images - 20
    		 */
    		do_action( 'woocommerce_before_single_product_summary' );
            
            $span_class = 9 - yit_get_span_from_width( yit_shop_large_w() + 8 );                   
    	?>
    
    	<div class="summary span<?php echo $span_class ?> entry-summary">
    
    		<?php
    			/**
    			 * woocommerce_single_product_summary hook
    			 *
    			 * @hooked woocommerce_template_single_title - 5
    			 * @hooked woocommerce_template_single_price - 10
    			 * @hooked woocommerce_template_single_excerpt - 20
    			 * @hooked woocommerce_template_single_add_to_cart - 30
    			 * @hooked woocommerce_template_single_meta - 40
    			 * @hooked woocommerce_template_single_sharing - 50
    			 */
    			do_action( 'woocommerce_single_product_summary' );
    		?>
    
    	</div><!-- .summary -->
    	<?php
    		/**
    		 * woocommerce_after_single_product_summary hook
    		 *
    		 * @hooked woocommerce_output_product_data_tabs - 10
    		 * @hooked woocommerce_output_related_products - 20
    		 */
    		do_action( 'woocommerce_after_single_product_summary' );
    	?>
    
</div>
<?php do_action( 'woocommerce_after_single_product' ); ?>

==> bazar1.6.1.zip: bazar1.6.1/woocommerce/content-single-product.php <==
<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * Override this template by copying it to yourtheme/woocommerce/content-single-product.php
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     1.6.4
 */                
wp_enqueue_script( 'jquery-selectbox' );   

// grouped fix
global $product;
if ( $product->product_type == 'grouped' && yit_get_option('shop-detail-show-price') ) {
    remove_action( 'yit_product_box', 'woocommerce_template_single_add_to_cart', 20 );
    add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
}
?>

<?php
	/**
	 * woocommerce_before_single_product hook
	 *
	 * @hooked woocommerce_show_messages - 10
	 */
	 do_action( 'woocommerce_before_single_product' );
?>
<div class="row">
    

    	<?php
    		/**
    		 * woocommerce_show_product_images hook
    		 *
    		 * @hooked woocommerce_show_product_sale_flash - 10
    		 * @hooked woocommerce_show_product_images - 20
    		 */
    		do_action( 'woocommerce_before_single_product_summary' );
    	?>
    
    	<div class="summary entry-summary">
    
    		<?php
    			/**
    			 * woocommerce_single_product_summary hook
    			 *
    			 * @hooked woocommerce_template_single_title - 5
    			 * @hooked woocommerce_template_single_price - 10
    			 * @hooked woocommerce_template_single_excerpt - 20
    			 * @hooked woocommerce_template_single_add_to_cart - 30
    			 * @hooked woocommerce_template_single_meta - 40
    			 * @hooked woocommerce_template_single_sharing - 50
    			 */
    			do_action( 'woocommerce_single_product_summary' );
    		?>
    
    	</div><!-- .summary -->
    	<?php
    		/**
    		 * woocommerce_after_single_product_summary hook
    		 *
    		 * @hooked woocommerce_output_product_data_tabs - 10
    		 * @hooked woocommerce_output_related_products - 20
    		 */
    		do_action( 'woocommerce_after_single_product_summary' );
    	?>
    
</div>
<?php do_action( 'woocommerce_after_single_product' ); ?>
